@@ -260,10 +260,8 @@ egg_toolbar_editor_class_init (EggToolbarEditorClass *klass)
 						       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 						       G_PARAM_CONSTRUCT));
 
-#if GTK_CHECK_VERSION (3, 20, 0)
   GtkWidgetClass *widget_class  = GTK_WIDGET_CLASS (klass);
   gtk_widget_class_set_css_name (widget_class, "EggToolbarEditor");
-#endif
 
   g_type_class_add_private (object_class, sizeof (EggToolbarEditorPrivate));
 }
@@ -537,29 +535,24 @@ append_grid (GtkGrid *grid, GList *items, gint y, gint width)
   if (items != NULL)
     {
       gint x = 0;
-      GtkWidget *alignment;
       GtkWidget *item;
 
       if (y > 0)
         {
           item = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
-          alignment = gtk_alignment_new (0.5, 0.5, 1.0, 0.0);
-          g_object_set (G_OBJECT (alignment), "expand", TRUE, NULL);
-          gtk_container_add (GTK_CONTAINER (alignment), item);
-          gtk_widget_show (alignment);
+          gtk_widget_set_hexpand (item, TRUE);
+          gtk_widget_set_vexpand (item, FALSE);
           gtk_widget_show (item);
 
-          gtk_grid_attach (grid, alignment, 0, y, width, 1);
+          gtk_grid_attach (grid, item, 0, y, width, 1);
           y++;
         }
 
       for (; items != NULL; items = items->next)
         {
           item = items->data;
-          alignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-          g_object_set (G_OBJECT (alignment), "expand", TRUE, NULL);
-          gtk_container_add (GTK_CONTAINER (alignment), item);
-          gtk_widget_show (alignment);
+          gtk_widget_set_hexpand (item, FALSE);
+          gtk_widget_set_vexpand (item, FALSE);
           gtk_widget_show (item);
 
           if (x >= width)
@@ -567,7 +560,7 @@ append_grid (GtkGrid *grid, GList *items, gint y, gint width)
               x = 0;
               y++;
             }
-          gtk_grid_attach (grid, alignment, x, y, 1, 1);
+          gtk_grid_attach (grid, item, x, y, 1, 1);
           x++;
         }
 
@@ -641,8 +634,8 @@ update_editor_sheet (EggToolbarEditor *editor)
     }
 
   /* Add grid to window. */
-  gtk_container_add
-    (GTK_CONTAINER (editor->priv->scrolled_window), grid);
+  gtk_scrolled_window_add_with_viewport
+    (GTK_SCROLLED_WINDOW (editor->priv->scrolled_window), grid);
 }
 
 static void
